"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var constants_1 = require("./lib/constants");
var floorTowardsZero_1 = require("./lib/floorTowardsZero");
var subtractTime_1 = require("./subtractTime");
var toYears_1 = require("./toYears");
var toMonths_1 = require("./toMonths");
var toWeeks_1 = require("./toWeeks");
var toDays_1 = require("./toDays");
var toHours_1 = require("./toHours");
var toMinutes_1 = require("./toMinutes");
var toSeconds_1 = require("./toSeconds");
var toMilliseconds_1 = require("./toMilliseconds");
var units = [
    {
        key: 'years',
        convertTo: toYears_1.default,
    },
    {
        key: 'months',
        convertTo: toMonths_1.default,
    },
    {
        key: 'weeks',
        convertTo: toWeeks_1.default,
    },
    {
        key: 'days',
        convertTo: toDays_1.default,
    },
    {
        key: 'hours',
        convertTo: toHours_1.default,
    },
    {
        key: 'minutes',
        convertTo: toMinutes_1.default,
    },
    {
        key: 'seconds',
        convertTo: toSeconds_1.default,
    },
    {
        key: 'milliseconds',
        convertTo: toMilliseconds_1.default,
    },
];
/**
 * Convert a `Time` object or number of milliseconds into a complete
 * `Time` object that expresses the time in the most appropriate units.
 *
 * @example
 * normalizeTime({ milliseconds 4000 })
 * // { years: 0, months: 0, weeks: 0, days: 0, hours: 0, minutes: 0, seconds: 4, milliseconds: 0 }
 */
var normalizeTime = function (time) {
    var _a;
    var tally = time;
    var output = __assign({}, constants_1.DEFAULT_TIME);
    for (var _i = 0, units_1 = units; _i < units_1.length; _i++) {
        var _b = units_1[_i], key = _b.key, convertTo = _b.convertTo;
        output[key] = floorTowardsZero_1.default(convertTo(tally));
        tally = subtractTime_1.default(tally, (_a = {}, _a[key] = output[key], _a));
    }
    return output;
};
exports.default = normalizeTime;
//# sourceMappingURL=normalizeTime.js.map