"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var constants_1 = require("./lib/constants");
var unitToKey = function (unit, context) {
    switch (unit.toUpperCase()) {
        case 'Y':
            return 'years';
        case 'M':
            if (context === 'period') {
                return 'months';
            }
            return 'minutes';
        case 'W':
            return 'weeks';
        case 'D':
            return 'days';
        case 'H':
            return 'hours';
        case 'S':
            return 'seconds';
        default:
            throw new SyntaxError("Unrecognised unit \"" + unit + "\" in ISO duration string");
    }
};
var addValue = function (obj, execResult, context) {
    var valueString = execResult[1], unit = execResult[2];
    var key = unitToKey(unit, context);
    var value = Number(valueString);
    if (isNaN(value)) {
        throw new SyntaxError("Non-numeric duration value \"" + valueString + "\" in ISO duration string");
    }
    obj[key] = value;
};
/**
 * Parse an ISO 8601 duration string into an object.
 *
 * The units of time are not normalized. For example, the string `"P365D"`
 * doesn't get converted to `{ years: 1 }` since not all years are the same
 * length.
 *
 * @example parseISODuration('P365D') // { days: 365 }
 */
exports.parseISODuration = function (duration) {
    var parsingRegex = /([^A-Z]+)([A-Z])/gi;
    var _a = duration.replace(/,/g, '.').split(/T/i), period = _a[0], time = _a[1];
    var output = __assign({}, constants_1.DEFAULT_TIME);
    var execResult;
    while (execResult = parsingRegex.exec(period)) {
        addValue(output, execResult, 'period');
    }
    while (execResult = parsingRegex.exec(time)) {
        addValue(output, execResult, 'time');
    }
    return output;
};
exports.default = exports.parseISODuration;
//# sourceMappingURL=parseISODuration.js.map