"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var parseISODuration_1 = require("./parseISODuration");
var constants_1 = require("./lib/constants");
/**
 * Get the number of milliseconds represented by a `Time` object.
 * If a number is passed this is returned verbatim as the number
 * of milliseconds.
 *
 * @example toMilliseconds({ days: 1 }) // 86400000
 */
var toMilliseconds = function (time) {
    if (typeof time === 'number') {
        return time;
    }
    var timeObject = typeof time === 'string'
        ? parseISODuration_1.default(time)
        : time;
    var _a = timeObject.years, years = _a === void 0 ? 0 : _a, _b = timeObject.months, months = _b === void 0 ? 0 : _b, _c = timeObject.weeks, weeks = _c === void 0 ? 0 : _c, _d = timeObject.days, days = _d === void 0 ? 0 : _d, _e = timeObject.hours, hours = _e === void 0 ? 0 : _e, _f = timeObject.minutes, minutes = _f === void 0 ? 0 : _f, _g = timeObject.seconds, seconds = _g === void 0 ? 0 : _g, _h = timeObject.milliseconds, milliseconds = _h === void 0 ? 0 : _h;
    return (years * constants_1.MILLISECONDS_IN_A_YEAR +
        months * constants_1.MILLISECONDS_IN_A_MONTH +
        weeks * constants_1.MILLISECONDS_IN_A_WEEK +
        days * constants_1.MILLISECONDS_IN_A_DAY +
        hours * constants_1.MILLISECONDS_IN_AN_HOUR +
        minutes * constants_1.MILLISECONDS_IN_A_MINUTE +
        seconds * constants_1.MILLISECONDS_IN_A_SECOND +
        milliseconds);
};
exports.default = toMilliseconds;
//# sourceMappingURL=toMilliseconds.js.map